==> slayersbeasts-fabric-1.21.1-5.2.0-sources.jar: net/invictusslayer/slayersbeasts/client/model/AntCargoModel.java <==
package net.invictusslayer.slayersbeasts.client.model;

import net.invictusslayer.slayersbeasts.SlayersBeasts;
import net.invictusslayer.slayersbeasts.world.entity.AntWorker;
import net.minecraft.class_2960;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_5601;
import net.minecraft.class_5603;
import net.minecraft.class_5605;
import net.minecraft.class_5606;
import net.minecraft.class_5607;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_583;
import net.minecraft.class_630;
import net.minecraft.client.model.geom.builders.*;

public class AntCargoModel<T extends AntWorker> extends class_583<T> {
	public static final class_5601 LAYER_LOCATION = new class_5601(class_2960.method_60655(SlayersBeasts.MOD_ID, "ant_worker_model"), "cargo");
	private final class_630 cargo;

	public AntCargoModel(class_630 root) {
		this.cargo = root.method_32086("cargo");
	}

	public void setupAnim(T entity, float limbSwing, float limbSwingAmount, float ageInTicks, float netHeadYaw, float headPitch) {}

	public void method_2828(class_4587 poseStack, class_4588 vertexConsumer, int packedLight, int packedOverlay, int colour) {
		cargo.method_22699(poseStack, vertexConsumer, packedLight, packedOverlay, colour);
	}

	public static class_5607 createCargoLayer() {
		class_5609 meshdefinition = new class_5609();
		class_5610 partdefinition = meshdefinition.method_32111();

		class_5610 cargo = partdefinition.method_32117("cargo", class_5606.method_32108().method_32101(5, 6).method_32098(-0.5F, -4.0F, -1.0F, 1.0F, 4.0F, 1.0F, new class_5605(0.0F))
				.method_32101(0, 0).method_32098(-0.5F, -5.0F, -3.0F, 1.0F, 5.0F, 2.0F, new class_5605(0.0F))
				.method_32101(6, 0).method_32098(-0.5F, -6.0F, -4.0F, 1.0F, 5.0F, 1.0F, new class_5605(0.0F))
				.method_32101(0, 7).method_32098(-0.5F, -5.0F, -5.0F, 1.0F, 3.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32090(0.0F, 21.75F, -5.0F));

		return class_5607.method_32110(meshdefinition, 16, 16);
	}
}

==> slayersbeasts-fabric-1.21.4-6.2.0-sources.jar: net/invictusslayer/slayersbeasts/client/model/AntCargoModel.java <==
package net.invictusslayer.slayersbeasts.client.model;

import net.invictusslayer.slayersbeasts.SlayersBeasts;
import net.invictusslayer.slayersbeasts.client.state.AntWorkerRenderState;
import net.minecraft.class_2960;
import net.minecraft.class_5601;
import net.minecraft.class_5603;
import net.minecraft.class_5605;
import net.minecraft.class_5606;
import net.minecraft.class_5607;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_583;
import net.minecraft.class_630;
import net.minecraft.client.model.geom.builders.*;

public class AntCargoModel extends class_583<AntWorkerRenderState> {
	public static final class_5601 LAYER_LOCATION = new class_5601(class_2960.method_60655(SlayersBeasts.MOD_ID, "ant_worker_model"), "cargo");
//	private final ModelPart cargo;

	public AntCargoModel(class_630 root) {
		super(root);
//		this.cargo = root.getChild("cargo");
	}

	public void setupAnim(AntWorkerRenderState state) {
		super.method_2819(state);
	}

	public static class_5607 createCargoLayer() {
		class_5609 meshdefinition = new class_5609();
		class_5610 partdefinition = meshdefinition.method_32111();

		class_5610 cargo = partdefinition.method_32117("cargo", class_5606.method_32108().method_32101(5, 6).method_32098(-0.5F, -4.0F, -1.0F, 1.0F, 4.0F, 1.0F, new class_5605(0.0F))
				.method_32101(0, 0).method_32098(-0.5F, -5.0F, -3.0F, 1.0F, 5.0F, 2.0F, new class_5605(0.0F))
				.method_32101(6, 0).method_32098(-0.5F, -6.0F, -4.0F, 1.0F, 5.0F, 1.0F, new class_5605(0.0F))
				.method_32101(0, 7).method_32098(-0.5F, -5.0F, -5.0F, 1.0F, 3.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32090(0.0F, 21.75F, -5.0F));

		return class_5607.method_32110(meshdefinition, 16, 16);
	}
}
